﻿namespace tippjatek
{
    internal class Program
    {
        static void Main(string[] args)
        {
            string filePath = Path.Combine(Directory.GetCurrentDirectory(), "tippek.csv");

            Dictionary<string, List<MatchPrediction>> playerPredictions = new Dictionary<string, List<MatchPrediction>>();
            Dictionary<string, string> playerTopScorerPredictions = new Dictionary<string, string>();
            Dictionary<string, string> playerWinnerPredictions = new Dictionary<string, string>();
            List<MatchResult> matchResults = new List<MatchResult>();
            string actualTopScorer = "";
            string actualWinner = "";

            try
            {
                var lines = File.ReadAllLines(filePath);
                var header = lines[0].Split(';');

                // Initialize players
                for (int i = 2; i < header.Length; i++)
                {
                    playerPredictions[header[i]] = new List<MatchPrediction>();
                    playerTopScorerPredictions[header[i]] = "";
                    playerWinnerPredictions[header[i]] = "";
                }

                // Read top scorer data
                var topScorerLine = lines[1].Split(';');
                actualTopScorer = topScorerLine[1];
                for (int i = 3; i < topScorerLine.Length; i++)
                {
                    playerTopScorerPredictions[header[i]] = topScorerLine[i];
                }

                // Read winner data
                var winnerLine = lines[2].Split(';');
                actualWinner = winnerLine[1];
                for (int i = 3; i < winnerLine.Length; i++)
                {
                    playerWinnerPredictions[header[i]] = winnerLine[i];
                }

                // Read match results and player predictions
                foreach (var line in lines.Skip(3))
                {
                    var values = line.Split(';');
                    var actualResult = values[1].Split('-');
                    var matchResult = new MatchResult
                    {
                        Match = values[0],
                        ActualHome = int.Parse(actualResult[0]),
                        ActualAway = int.Parse(actualResult[1])
                    };
                    matchResults.Add(matchResult);

                    for (int i = 2; i < values.Length; i++)
                    {
                        var predictionParts = values[i].Split('-');
                        var prediction = new MatchPrediction
                        {
                            PredictedHome = int.Parse(predictionParts[0]),
                            PredictedAway = int.Parse(predictionParts[1])
                        };
                        playerPredictions[header[i]].Add(prediction);
                    }
                }
            }
            catch (Exception ex)
            {
                Console.WriteLine("Hiba történt a fájl beolvasásakor: " + ex.Message);
                return;
            }

            Dictionary<string, int> playerScores = new Dictionary<string, int>();

            foreach (var player in playerPredictions)
            {
                int totalPoints = 0;
                for (int i = 0; i < matchResults.Count; i++)
                {
                    totalPoints += CalculatePoints(player.Value[i], matchResults[i]);
                }

                if (playerTopScorerPredictions[player.Key] == actualTopScorer)
                {
                    totalPoints += 15; // Gólkirály eltalálása
                }

                if (playerWinnerPredictions[player.Key] == actualWinner)
                {
                    totalPoints += 15; // Végső győztes eltalálása
                }

                playerScores[player.Key] = totalPoints;
            }

            var sortedScores = playerScores.OrderByDescending(x => x.Value).ToList();

            Console.WriteLine("Eredmények:");
            int rank = 1;
            for (int i = 0; i < sortedScores.Count; i++)
            {
                if (i > 0 && sortedScores[i].Value != sortedScores[i - 1].Value)
                {
                    rank = i + 1;
                }
                Console.WriteLine($"{rank}. helyezett {sortedScores[i].Key} {sortedScores[i].Value} ponttal");
            }
            Console.ReadKey();
        }

        static int CalculatePoints(MatchPrediction prediction, MatchResult result)
        {
            int points = 0;

            if (prediction.PredictedHome == result.ActualHome && prediction.PredictedAway == result.ActualAway)
            {
                points += 10; // Pontos végeredmény
            }
            else if ((prediction.PredictedHome - prediction.PredictedAway == result.ActualHome - result.ActualAway) &&
                     ((prediction.PredictedHome > prediction.PredictedAway && result.ActualHome > result.ActualAway) ||
                      (prediction.PredictedHome < prediction.PredictedAway && result.ActualAway > result.ActualAway) ||
                      (prediction.PredictedHome == prediction.PredictedAway && result.ActualHome == result.ActualAway)))
            {
                points += 6; // Gólkülönbség és kimenetel
            }
            else if ((prediction.PredictedHome > prediction.PredictedAway && result.ActualHome > result.ActualAway) ||
                     (prediction.PredictedHome < prediction.PredictedAway && result.ActualAway > result.ActualAway) ||
                     (prediction.PredictedHome == prediction.PredictedAway && result.ActualHome == result.ActualAway))
            {
                points += 4; // Mérkőzés kimenetelének eltalálása
            }

            if (prediction.PredictedHome == result.ActualHome || prediction.PredictedAway == result.ActualAway)
            {
                points += 3; // Az egyik csapat góljainak eltalálása
            }

            if (prediction.PredictedHome + prediction.PredictedAway == result.ActualHome + result.ActualAway)
            {
                points += 2; // Összes szerzett gól eltalálása
            }

            if (prediction.PredictedHome - prediction.PredictedAway == -(result.ActualHome - result.ActualAway))
            {
                points += 1; // Gólkülönbség eltalálása fordított eredménnyel
            }

            return points;
        }


        class MatchResult
        {
            public string Match { get; set; }
            public int ActualHome { get; set; }
            public int ActualAway { get; set; }
        }

        class MatchPrediction
        {
            public int PredictedHome { get; set; }
            public int PredictedAway { get; set; }
        }
    }
}





